==> centreon-web-24.10.14.tar.gz: centreon-web-24.10.14/tests/php/Core/Security/Vault/Application/UseCase/FindVaultConfiguration/FindVaultConfigurationPresenterStub.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Tests\Core\Security\Vault\Application\UseCase\FindVaultConfiguration;

use Core\Application\Common\UseCase\{AbstractPresenter, PresenterInterface, ResponseStatusInterface};
use Core\Security\Vault\Application\UseCase\FindVaultConfiguration\FindVaultConfigurationPresenterInterface;
use Core\Security\Vault\Application\UseCase\FindVaultConfiguration\FindVaultConfigurationResponse;

class FindVaultConfigurationPresenterStub extends AbstractPresenter implements FindVaultConfigurationPresenterInterface
{
    /**
     * @var FindVaultConfigurationResponse|ResponseStatusInterface
     */
    public FindVaultConfigurationResponse|ResponseStatusInterface $data;

    public function presentResponse(FindVaultConfigurationResponse|ResponseStatusInterface $data): void
    {
        $this->data = $data;
    }
}

==> centreon-web-25.10.4.tar.gz: centreon-web-25.10.4/tests/php/Core/Security/Vault/Application/UseCase/FindVaultConfiguration/FindVaultConfigurationPresenterStub.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Tests\Core\Security\Vault\Application\UseCase\FindVaultConfiguration;

use Core\Application\Common\UseCase\{AbstractPresenter, ResponseStatusInterface};
use Core\Security\Vault\Application\UseCase\FindVaultConfiguration\FindVaultConfigurationPresenterInterface;
use Core\Security\Vault\Application\UseCase\FindVaultConfiguration\FindVaultConfigurationResponse;

class FindVaultConfigurationPresenterStub extends AbstractPresenter implements FindVaultConfigurationPresenterInterface
{
    /**
     * @var FindVaultConfigurationResponse|ResponseStatusInterface
     */
    public FindVaultConfigurationResponse|ResponseStatusInterface $data;

    public function presentResponse(FindVaultConfigurationResponse|ResponseStatusInterface $data): void
    {
        $this->data = $data;
    }
}
